﻿using System;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Wpf;

namespace OriStarRasterWithNuGet
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        string dataPath = string.Format("{0}", @"..\..\Data");

        public MainWindow()
        {
            InitializeComponent();
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            wpfMap1.MapUnit = GeographyUnit.DecimalDegree;

            LayerOverlay staticOverlay = new LayerOverlay();
            staticOverlay.Layers.Add("mrsid", LoadMrsid());
            wpfMap1.Overlays.Add(staticOverlay);

            try
            {
                //wpfMap1.CurrentExtent = new RectangleShape(-118.098, 84.3, 118.098, -84.3);

                // uncomment of the next line results in exception of "Value cannot be null.\r\nParameter name: ptr"
                wpfMap1.CurrentExtent = staticOverlay.GetBoundingBox();

                // when the above line is commented an exception occurs sometime after the wpfMap1.Refresh                
            }
            catch (Exception ex)
            {
                string sInform = String.Format("Unable to GetBoundingBox{0}Message={1}", Environment.NewLine, ex.Message);
                System.Windows.MessageBox.Show(sInform, "WpfMap_Loaded", System.Windows.MessageBoxButton.OK, System.Windows.MessageBoxImage.Error);
                return;
            }

            wpfMap1.Refresh();
        }


        private Layer LoadMrsid()
        {
            MrSidRasterLayer layer = new MrSidRasterLayer(dataPath + @"\world.sid");
            layer.Open();
            layer.DrawingException += SidImageLayer_DrawingException;
            layer.DrawnException += SidImageLayer_DrawnException;

            layer.UpperThreshold = double.MaxValue;
            layer.LowerThreshold = 0;

            return layer;
        }

        private Layer LoadJpeg2000()
        {
            Jpeg2000RasterLayer layer = new Jpeg2000RasterLayer(dataPath + @"\World.jp2");
            layer.Open();
            layer.UpperThreshold = double.MaxValue;
            layer.LowerThreshold = 0;

            return layer;
        }

        private void btnJpeg2000_Click(object sender, RoutedEventArgs e)
        {
            LayerOverlay staticOverlay = new LayerOverlay();
            staticOverlay.Layers.Add("jpeg2000", LoadJpeg2000());
            wpfMap1.Overlays.Clear();
            wpfMap1.Overlays.Add(staticOverlay);
            wpfMap1.CurrentExtent = staticOverlay.GetBoundingBox();

            wpfMap1.Refresh();
        }

        private void btnMrsid_Click(object sender, RoutedEventArgs e)
        {
            LayerOverlay staticOverlay = new LayerOverlay();
            staticOverlay.Layers.Add("mrsid", LoadMrsid());
            wpfMap1.Overlays.Clear();
            wpfMap1.Overlays.Add(staticOverlay);
            wpfMap1.CurrentExtent = staticOverlay.GetBoundingBox();

            wpfMap1.Refresh();
        }

        // this event is never encountered
        private void SidImageLayer_DrawingException(object sender, DrawingExceptionLayerEventArgs e)
        {
            string sInform = String.Format("Exception{0}Message={1}", Environment.NewLine, e.Exception.Message);
            System.Windows.MessageBox.Show(sInform, "SidImageLayer_DrawingException", System.Windows.MessageBoxButton.OK, System.Windows.MessageBoxImage.Error);
        }

        // this event is never encountered
        private void SidImageLayer_DrawnException(object sender, DrawnExceptionLayerEventArgs e)
        {
            string sInform = String.Format("Exception{0}Message={1}", Environment.NewLine, e.Exception.Message);
            System.Windows.MessageBox.Show(sInform, "SidImageLayer_DrawnException", System.Windows.MessageBoxButton.OK, System.Windows.MessageBoxImage.Error);
        }

    }
}
